@@ -13,9 +13,9 @@
 """this module contains a set of functions to handle inference on astng trees
 
 :author:    Sylvain Thenault
-:copyright: 2003-2007 LOGILAB S.A. (Paris, FRANCE)
+:copyright: 2003-2008 LOGILAB S.A. (Paris, FRANCE)
 :contact:   http://www.logilab.fr/ -- mailto:python-projects@logilab.org
-:copyright: 2003-2007 Sylvain Thenault
+:copyright: 2003-2008 Sylvain Thenault
 :contact:   mailto:thenault@gmail.com
 """
 
@@ -645,9 +645,24 @@ nodes.For.assigned_stmts = for_assigned_stmts
 nodes.ListCompFor.assigned_stmts = for_assigned_stmts
 nodes.GenExprFor.assigned_stmts = for_assigned_stmts
 
+def with_assigned_stmts(self, node, context=None, asspath=None):
+    found = False
+    if asspath is None:
+        for lst in self.vars.infer(context):
+            if isinstance(lst, (nodes.Tuple, nodes.List)):
+                for item in lst.nodes:
+                    found = True
+                    yield item
+    else:
+        raise InferenceError()
+    if not found:
+        raise InferenceError()
+nodes.With.assigned_stmts = with_assigned_stmts
+
     
 def end_ass_type(self):
     return self
+nodes.With.ass_type = end_ass_type
 nodes.For.ass_type = end_ass_type
 nodes.ListCompFor.ass_type = end_ass_type
 nodes.GenExprFor.ass_type = end_ass_type
