@@ -19,11 +19,10 @@ Function...) nodes:
 Be careful, lookup is kinda internal and return a tuple (scope, [stmts]), while
 ilookup return an iterator on infered values
 
-:version:   $Revision: 1.6 $  
 :author:    Sylvain Thenault
-:copyright: 2003-2006 LOGILAB S.A. (Paris, FRANCE)
+:copyright: 2003-2007 LOGILAB S.A. (Paris, FRANCE)
 :contact:   http://www.logilab.fr/ -- mailto:python-projects@logilab.org
-:copyright: 2003-2006 Sylvain Thenault
+:copyright: 2003-2007 Sylvain Thenault
 :contact:   mailto:thenault@gmail.com
 """
 
@@ -34,7 +33,7 @@ __docformat__ = "restructuredtext en"
 import __builtin__
 
 from logilab.astng.utils import are_exclusive
-from logilab.astng import MANAGER, _infer_stmts
+from logilab.astng import nodes, MANAGER, _infer_stmts, copy_context
 
 
 def lookup(self, name):
@@ -59,8 +58,14 @@ def scope_lookup(self, node, name, offset=0):
     if stmts:
         return self, stmts
     if self.parent:
-        return self.parent.scope().scope_lookup(node, name)
+        # nested scope: if parent scope is a function, that's fine
+        # else jump to the module
+        pscope = self.parent.scope()
+        if not isinstance(pscope, nodes.Function):
+            pscope = pscope.root()
+        return pscope.scope_lookup(node, name)
     return builtin_lookup(name)
+
 def class_scope_lookup(self, node, name, offset=0):
     if node in self.bases:
         #print 'frame swaping'
@@ -71,6 +76,7 @@ def class_scope_lookup(self, node, name, offset=0):
     else:
         frame = self
     return scope_lookup(frame, node, name, offset)
+
 def function_scope_lookup(self, node, name, offset=0):
     if node in self.defaults:
         frame = self.parent.frame()
@@ -78,6 +84,7 @@ def function_scope_lookup(self, node, name, offset=0):
         # value to the defined function
         offset = -1
     else:
+        # check this is not used in function decorators
         frame = self
     return scope_lookup(frame, node, name, offset)
     
@@ -93,14 +100,16 @@ def builtin_lookup(name):
         stmts = ()
     return builtinastng, stmts
 
-def ilookup(self, name, path=None):
+def ilookup(self, name, context=None):
     """infered lookup
     
     return an iterator on infered values of the statements returned by
     the lookup method
     """
     frame, stmts = self.lookup(name)
-    return _infer_stmts(stmts, name, path, frame)
+    context = copy_context(context)
+    context.lookupname = name
+    return _infer_stmts(stmts, context, frame)
 
 
 def _filter_stmts(self, stmts, frame, offset):
@@ -149,8 +158,6 @@ def _filter_stmts(self, stmts, frame, offset):
                 if not isinstance(ass_type, (ListCompFor,  GenExprFor)):
                     #print 'break now2', self, ass_type
                     break
-                #print list(ass_type.assigned_stmts())
-                #if ass_type.assigned_stmts()
                 if isinstance(self, (Const, Name)):
                     _stmts = [self]
                     #print 'break now', ass_type, self, node
