@@ -73,8 +73,16 @@ except:
     class Decorators:
         """dummy Decorators node, shouldn't be used since py < 2.4"""
 
+try:
+    # introduced in python 2.5
+    from compiler.ast import With
+except:
+    class With:
+        """dummy With node, shouldn't be used since py < 2.5"""
+
 from logilab.astng._exceptions import NotFoundError, InferenceError
 from logilab.astng.utils import extend_class
+from logilab.astng import InferenceContext
 
 import re
 ID_RGX = re.compile('^[a-zA-Z_][a-zA-Z_0-9]*$')
@@ -235,7 +243,7 @@ class NodeNG:
         for child_node in self.getChildNodes():
             if skip_klass is not None and isinstance(child_node, skip_klass):
                 continue
-            for matching in child_node.nodes_of_class(klass):
+            for matching in child_node.nodes_of_class(klass, skip_klass):
                 yield matching
 
     def _infer_name(self, frame, name):
@@ -334,6 +342,11 @@ def real_name(node, asname):
 From.real_name = real_name
 Import.real_name = real_name
 
+def infer_name_module(node, name):
+    context = InferenceContext(node)
+    context.lookupname = name
+    return node.infer(context, asname=False)
+Import.infer_name_module = infer_name_module
 
 # as_string ###################################################################
 
@@ -771,6 +784,14 @@ def while_as_string(node):
     return whiles
 While.as_string = while_as_string
 
+def with_as_string(node):
+    """return an ast.With node as string"""
+    withs = 'with (%s) as (%s):\n    %s' % (node.expr.as_string(),
+                                      node.vars.as_string(),
+                                      node.body.as_string())
+    return withs
+With.as_string = with_as_string
+
 def yield_as_string(node):
     """yield an ast.Yield node as string"""
     return 'yield %s' % node.value.as_string()
