@@ -16,7 +16,8 @@
 import sys
 from logilab.common.testlib import TestCase, unittest_main
 
-from logilab.astng import builder, nodes, inference, YES, Instance
+from logilab.astng import builder, nodes, inference, YES, Instance, \
+     InstanceMethod
 
 def get_name_node(start_from, name, index=0):
     return [n for n in start_from.nodes_of_class(nodes.Name) if n.name == name][index]
@@ -60,6 +61,8 @@ class C(object):
     
 ex = exceptions.Exception("msg")
 v = C().meth1(1)
+m_unbound = C.meth1
+m_bound = C().meth1
 a, b, c = ex, 1, "bonjour"
 [d, e, f] = [ex, 1.0, ("bonjour", v)]
 g, h = f
@@ -213,6 +216,22 @@ a, b= b, a # Gasp !
         self.failUnlessEqual(meth1.root().name, '__builtin__')
         self.failUnlessRaises(StopIteration, infered.next)
 
+    def test_unbound_method_inference(self):
+        infered = self.astng['m_unbound'].infer()
+        meth1 = infered.next()
+        self.failUnless(isinstance(meth1, nodes.Function))
+        self.failUnlessEqual(meth1.name, 'meth1')
+        self.failUnlessEqual(meth1.parent.frame().name, 'C')
+        self.failUnlessRaises(StopIteration, infered.next)
+
+    def test_bound_method_inference(self):
+        infered = self.astng['m_bound'].infer()
+        meth1 = infered.next()
+        self.failUnless(isinstance(meth1, InstanceMethod))
+        self.failUnlessEqual(meth1.name, 'meth1')
+        self.failUnlessEqual(meth1.parent.frame().name, 'C')
+        self.failUnlessRaises(StopIteration, infered.next)
+
     def test_args_default_inference1(self):
         optarg = get_name_node(self.astng['C']['meth1'], 'optarg')
         infered = optarg.infer()
@@ -448,8 +467,8 @@ xxx = load_module_from_name('__pkginfo__')
         astng = builder.string_build(data, __name__, __file__)
         xxx = astng['xxx']
         infered = list(xxx.infer())
-        self.failUnlessEqual([n.__class__ for n in infered],
-                             [nodes.Const, YES.__class__])
+        self.failUnlessEqual(sorted([n.__class__ for n in infered]),
+                             sorted([nodes.Const, YES.__class__]))
 
     def test_method_argument(self):
         data = '''
@@ -617,6 +636,8 @@ print ((d,e) for e,d in ([1,2], [3,4]))
         data = '''
 help()
         '''
+        # XXX failing with python > 2.3 since __builtin__.help assigment has
+        #     been moved into a function...
         astng = builder.string_build(data, __name__, __file__)
         node = get_name_node(astng, 'help', -1)
         infered = list(node.infer())
